import {
  APIRequest,
  APIResponse,
  APIEncoder,
  APIDecoder,
  ParameterUtil
} from '@ucap-webmessenger/api';
import { DeviceType } from '@ucap-webmessenger/core';
import { CategoryType } from '../types/category.type';
import { ContentType } from '../types/content.type';

export interface EditReservationRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  msgId: number;
  category: CategoryType;
  title: string;
  titleYn: boolean;
  listOrder: ContentType[];
  reservationTime: string;
  smsYn: boolean;

  textContent: { text: string }[];
  recvUserList: { userSeq: number; userName: string }[];
}

export interface EditReservationResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
}

const EditReservationEncodeMap = {};

export const encodeEditReservation: APIEncoder<EditReservationRequest> = (
  req: EditReservationRequest
) => {
  return ParameterUtil.encode(EditReservationEncodeMap, req);
};

export const decodeEditReservation: APIDecoder<EditReservationResponse> = (
  res: any
) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg
  } as EditReservationResponse;
};
