import {
  APIRequest,
  APIResponse,
  APIEncoder,
  APIDecoder,
  ParameterUtil
} from '@ucap-webmessenger/api';
import { DeviceType } from '@ucap-webmessenger/core';

export interface SaveMyRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  userName: string;
  message: string;
}

export interface SaveMyResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
}

const SaveMyEncodeMap = {};

export const encodeSaveMy: APIEncoder<SaveMyRequest> = (req: SaveMyRequest) => {
  return ParameterUtil.encode(SaveMyEncodeMap, req);
};

export const decodeSaveMy: APIDecoder<SaveMyResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg
  } as SaveMyResponse;
};

export interface RetrieveMyRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  pageSize: number;
  pageCount: number;
}

export interface RetrieveMyResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;

  msgList: {
    msgId: number;
    message: string;
  }[];
}

const RetrieveMyEncodeMap = {};

export const encodeRetrieveMy: APIEncoder<RetrieveMyRequest> = (
  req: RetrieveMyRequest
) => {
  return ParameterUtil.encode(RetrieveMyEncodeMap, req);
};

export const decodeRetrieveMy: APIDecoder<RetrieveMyResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,

    msgList: []
  } as RetrieveMyResponse;
};

export interface DelMyRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
}

export interface DelMyResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
}

const DelMyEncodeMap = {};

export const encodeDelMy: APIEncoder<DelMyRequest> = (req: DelMyRequest) => {
  return ParameterUtil.encode(DelMyEncodeMap, req);
};

export const decodeDelMy: APIDecoder<DelMyResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg
  } as DelMyResponse;
};

export interface EditMyRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  msgId: number;
  message: string;
}

export interface EditMyResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
}

const EditMyEncodeMap = {};

export const encodeEditMy: APIEncoder<EditMyRequest> = (req: EditMyRequest) => {
  return ParameterUtil.encode(EditMyEncodeMap, req);
};

export const decodeEditMy: APIDecoder<EditMyResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg
  } as EditMyResponse;
};
