import {
  APIRequest,
  APIResponse,
  APIEncoder,
  APIDecoder,
  ParameterUtil
} from '@ucap-webmessenger/api';
import { DeviceType } from '@ucap-webmessenger/core';
import { MessageType } from '../types/message.type';
import { MessageList } from '../models/message-list';

export interface RetrieveRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  type: MessageType;
  pageSize: number;
  pageCount: number;
}
export interface RetrieveSearchRequest extends RetrieveRequest {
  searchTitle: string;
  searchName: string;
  searchContent: string;
}

export interface RetrieveResponse extends APIResponse {
  responseCode: string;
  responseMsg: string;
  totalCount: number;

  messageList: MessageList[];
}

const RetrieveEncodeMap = {};
const RetrieveSearchEncodeMap = {};

export const encodeRetrieve: APIEncoder<RetrieveRequest> = (
  req: RetrieveRequest
) => {
  return ParameterUtil.encode(RetrieveEncodeMap, req);
};
export const encodeRetrieveSearch: APIEncoder<RetrieveResponse> = (
  req: RetrieveResponse
) => {
  return ParameterUtil.encode(RetrieveSearchEncodeMap, req);
};

export const decodeRetrieveSend: APIDecoder<RetrieveResponse> = (res: any) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveReceive: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveReservation: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveSearch: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    statusCode: res.StatusCode,
    errorMessage: res.ErrorMessage,

    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};
